import request from '@/utils/request'
// 查询调用记录列表
export function listJxHorizonInvoke(query) {
  return request({
    url: '/jx_horizon/jxHorizonInvoke/list',
    method: 'get',
    params: query
  })
}
// 查询调用记录详细
export function getJxHorizonInvoke(id) {
  return request({
    url: '/jx_horizon/jxHorizonInvoke/get',
    method: 'get',
    params: {
     id: id.toString()
    }
  })
}
// 新增调用记录
export function addJxHorizonInvoke(data) {
  return request({
    url: '/jx_horizon/jxHorizonInvoke/add',
    method: 'post',
    data: data
  })
}
// 修改调用记录
export function updateJxHorizonInvoke(data) {
  return request({
    url: '/jx_horizon/jxHorizonInvoke/edit',
    method: 'put',
    data: data
  })
}
// 删除调用记录
export function delJxHorizonInvoke(ids) {
  return request({
    url: '/jx_horizon/jxHorizonInvoke/delete',
    method: 'delete',
    data:{
       ids:ids
    }
  })
}
// 调用记录AI返回状态修改
export function changeJxHorizonInvokeStatus(id,status) {
  const data = {
    id,
    status
  }
  return request({
    url: '/jx_horizon/jxHorizonInvoke/changeStatus',
    method: 'put',
    data:data
  })
}
// 调用记录当前请求状态修改
export function changeJxHorizonInvokeVendorStatus(id,vendorStatus) {
  const data = {
    id,
    vendorStatus
  }
  return request({
    url: '/jx_horizon/jxHorizonInvoke/changeVendorStatus',
    method: 'put',
    data:data
  })
}