<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" label-width="68px">    
      <el-form-item label="当前系统id" prop="orderId">
        <el-input
            v-model="queryParams.orderId"
            placeholder="请输入当前系统id"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>    
      <el-form-item label="AI返回状态" prop="status">
        <el-select v-model="queryParams.status" placeholder="请选择AI返回状态" clearable size="small">
            <el-option
                v-for="dict in statusOptions"
                :key="dict.key"
                :label="dict.value"
                :value="dict.key"
            />
        </el-select>
      </el-form-item>    
      <el-form-item label="AI平台" prop="vendorId">
        <el-select v-model="queryParams.vendorId" placeholder="请选择AI平台" clearable size="small">
            <el-option
                v-for="dict in vendorIdOptions"
                :key="dict.key"
                :label="dict.value"
                :value="dict.key"
            />
        </el-select>
      </el-form-item>      
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['jx_horizon/jxHorizonInvoke/add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['jx_horizon/jxHorizonInvoke/edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['jx_horizon/jxHorizonInvoke/delete']"
        >删除</el-button>
      </el-col>
    </el-row>
    <el-table v-loading="loading" :data="jxHorizonInvokeList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />      
      <el-table-column label="创建时间" align="center" prop="createdAt" width="180">
        <template slot-scope="scope">
            <span>{{ parseTime(scope.row.createdAt, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>      
      <el-table-column label="系统id" align="center" prop="id" />      
      <el-table-column label="系统用户ID" align="center" prop="userId" />      
      <el-table-column label="当前系统id" align="center" prop="orderId" />      
      <el-table-column label="当前订单支付金额" align="center" prop="payMoney" />      
      <el-table-column label="AI返回状态" align="center">
        <template slot-scope="scope">
            <el-switch
              v-model="scope.row.status"
              :active-value="1"
              :inactive-value="0"
              @change="statusChange(scope.row)"
            ></el-switch>
        </template>
      </el-table-column>      
      <el-table-column label="AI平台" align="center" prop="vendorId" :formatter="vendorIdFormat" />      
      <el-table-column label="用户描述信息" align="center" prop="userDescription" />      
      <el-table-column label="平台返回信息" align="center" prop="vendorDescription" />      
      <el-table-column label="平台价格" align="center" prop="vendorPrice" />      
      <el-table-column label="京西价格" align="center" prop="jxPrice" />      
      <el-table-column label="请求token长度" align="center" prop="tokens" />      
      <el-table-column label="返回图片链接(京西链接)" align="center" prop="urls" />      
      <el-table-column label="当前请求状态" align="center">
        <template slot-scope="scope">
            <el-switch
              v-model="scope.row.vendorStatus"
              :active-value="1"
              :inactive-value="0"
              @change="vendorStatusChange(scope.row)"
            ></el-switch>
        </template>
      </el-table-column>      
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['jx_horizon/jxHorizonInvoke/edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['jx_horizon/jxHorizonInvoke/delete']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
    <!-- 添加或修改调用记录对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="800px" append-to-body :close-on-click-modal="false">
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">      
      <el-form-item label="系统用户ID" prop="userId">
           <el-input v-model="form.userId" placeholder="请输入系统用户ID" />
      </el-form-item>      
      <el-form-item label="当前系统id" prop="orderId">
           <el-input v-model="form.orderId" placeholder="请输入当前系统id" />
      </el-form-item>      
      <el-form-item label="当前订单支付金额" prop="payMoney">
           <el-input v-model="form.payMoney" placeholder="请输入当前订单支付金额" />
      </el-form-item>      
       <el-form-item label="AI返回状态" prop="status">
           <el-radio-group v-model="form.status">
               <el-radio
                v-for="dict in statusOptions"
                :key="dict.key"
                :label="dict.key"
               >{{dict.value }}</el-radio>
           </el-radio-group>
       </el-form-item>      
       <el-form-item label="AI平台" prop="vendorId">
           <el-radio-group v-model="form.vendorId">
               <el-radio
                v-for="dict in vendorIdOptions"
                :key="dict.key"
                :label="dict.key"
               >{{dict.value }}</el-radio>
           </el-radio-group>
       </el-form-item>      
      <el-form-item label="用户描述信息" prop="userDescription">
           <el-input v-model="form.userDescription" placeholder="请输入用户描述信息" />
      </el-form-item>      
      <el-form-item label="平台返回信息" prop="vendorDescription">
           <el-input v-model="form.vendorDescription" placeholder="请输入平台返回信息" />
      </el-form-item>      
      <el-form-item label="平台价格" prop="vendorPrice">
           <el-input v-model="form.vendorPrice" placeholder="请输入平台价格" />
      </el-form-item>      
      <el-form-item label="京西价格" prop="jxPrice">
           <el-input v-model="form.jxPrice" placeholder="请输入京西价格" />
      </el-form-item>      
      <el-form-item label="请求token长度" prop="tokens">
           <el-input v-model="form.tokens" placeholder="请输入请求token长度" />
      </el-form-item>      
      <el-form-item label="返回图片链接(京西链接)" prop="urls">
           <el-input v-model="form.urls" placeholder="请输入返回图片链接(京西链接)" />
      </el-form-item>      
      <el-form-item label="当前请求状态" prop="vendorStatus">
           <el-input v-model="form.vendorStatus" placeholder="请输入当前请求状态" />
      </el-form-item>       
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>
<script>
import {
    listJxHorizonInvoke,
    getJxHorizonInvoke,
    delJxHorizonInvoke,
    addJxHorizonInvoke,
    updateJxHorizonInvoke,    
    changeJxHorizonInvokeStatus,    
    changeJxHorizonInvokeVendorStatus,    
} from "@/api/jx_horizon/jxHorizonInvoke";
export default {
  components:{    
  },
  name: "JxHorizonInvoke",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 总条数
      total: 0,
      // 调用记录表格数据
      jxHorizonInvokeList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,      
      // statusOptions字典数据
      statusOptions: [],      
      // vendorIdOptions字典数据
      vendorIdOptions: [],      
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        createdAt: undefined,
        orderId: undefined,
        status: undefined,
        vendorId: undefined,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: { 
        createdAt : [
          { required: true, message: "创建时间不能为空", trigger: "blur" }
        ],
        userId : [
          { required: true, message: "系统用户ID不能为空", trigger: "blur" }
        ],
        orderId : [
          { required: true, message: "当前系统id不能为空", trigger: "blur" }
        ],
        payMoney : [
          { required: true, message: "当前订单支付金额不能为空", trigger: "blur" }
        ],
        status : [
          { required: true, message: "AI返回状态不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {    
    this.getDicts("sys_success_fail").then(response => {
      this.statusOptions = response.data.values||[];
    });    
    this.getDicts("sys_access_platform").then(response => {
      this.vendorIdOptions = response.data.values||[];
    });
    this.getList();
  },
  methods: {    
    // AI返回状态修改
    statusChange(row) {
      let text = row.status === 1 ? "启用" : "停用";
      this.$confirm('确认要"' + text + '"：吗?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return changeJxHorizonInvokeStatus(row.id, row.status);
        }).then(() => {
          this.msgSuccess(text + "成功");
        }).catch(function() {
          row.userStatus =row.userStatus === 0 ?1 : 0;
        });
    },    
    // 当前请求状态修改
    vendorStatusChange(row) {
      let text = row.vendorStatus === 1 ? "启用" : "停用";
      this.$confirm('确认要"' + text + '"：吗?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return changeJxHorizonInvokeVendorStatus(row.id, row.vendorStatus);
        }).then(() => {
          this.msgSuccess(text + "成功");
        }).catch(function() {
          row.userStatus =row.userStatus === 0 ?1 : 0;
        });
    },    
    /** 查询调用记录列表 */
    getList() {
      this.loading = true;
      listJxHorizonInvoke(this.queryParams).then(response => {
        let list = response.data.list || [];        
        this.jxHorizonInvokeList = list;        
        this.total = response.data.total;
        this.loading = false;
      });
    },    
    // AI返回状态字典翻译
    statusFormat(row, column) {
      return this.selectDictLabel(this.statusOptions, row.status);
    },    
    // AI平台字典翻译
    vendorIdFormat(row, column) {
      return this.selectDictLabel(this.vendorIdOptions, row.vendorId);
    },    
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {        
        createdAt: undefined,        
        updatedAt: undefined,        
        id: undefined,        
        userId: undefined,        
        orderId: undefined,        
        payMoney: undefined,        
        status: "0" ,        
        vendorId: "0" ,        
        userDescription: undefined,        
        vendorDescription: undefined,        
        vendorPrice: undefined,        
        jxPrice: undefined,        
        tokens: undefined,        
        urls: undefined,        
        vendorStatus: undefined,        
      };      
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!=1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加调用记录";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getJxHorizonInvoke(id).then(response => {
        let data = response.data;        
        data.status = ''+data.status        
        data.vendorId = ''+data.vendorId        
        this.form = data;
        this.open = true;
        this.title = "修改调用记录";
      });
    },
    /** 提交按钮 */
    submitForm: function() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != undefined) {
            updateJxHorizonInvoke(this.form).then(response => {
              if (response.code === 0) {
                this.msgSuccess("修改成功");
                this.open = false;
                this.getList();
              } else {
                this.msgError(response.msg);
              }
            });
          } else {
            addJxHorizonInvoke(this.form).then(response => {
              if (response.code === 0) {
                this.msgSuccess("新增成功");
                this.open = false;
                this.getList();
              } else {
                this.msgError(response.msg);
              }
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm('是否确认删除调用记录编号为"' + ids + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delJxHorizonInvoke(ids);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(function() {});
    }
  }
};
</script>
<style>
</style>